"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * Badging for PWA app icons
 *
 * The App Badging API allows installed web apps to set an application-wide badge on the app icon.
 *
 * In some cases, the OS may not allow the exact representation of the badge.
 * In such cases, the browser will attempt to provide the best representation for that device.
 * For example, because the Badging API isn't supported on Android, Android only ever shows a dot instead of a numeric value.
 *
 * @class
 * @namespace PWABadge
 * @example Sync Set Badge.
 * const AppBadge = new PWABadge();
 * AppBadge.syncSetBadge(10)
 * @example Async Set Badge
 * const AppBadge = new PWABadge();
 * AppBadge.asyncSetBadge(10).then(() => {
 *   // Do something...
 * }).catch(e => {
 *   // Do something with the error.
 * })
 * @example Sync Clear Badge value
 * const AppBadge = new PWABadge();
 * AppBadge.syncClearBadge()
 * @example Async Clear Badge value
 * AppBadge.asyncClearBadge().then(() => {
 *   // Do something...
 * }).catch(e => {
 *   // Do something with the error.
 * })
 */
var PWABadge = /*#__PURE__*/function () {
  function PWABadge() {
    _classCallCheck(this, PWABadge);

    /**
     * @private
     * @type        {Navigator}
     * @description A Clone of navigator object
     */
    this.__navigator = window.navigator;
    /**
     * @private
     * @type        {Window}
     * @description A Clone of window object
     */

    this.__window = window;
  }
  /**
   * Check the Browser Badge feature supports
   *
   * @memberof  PWABadge
   * @return    {boolean} Return true if the browser supports the Badge feature and returns false if not.
   */


  _createClass(PWABadge, [{
    key: "supports",
    value: function supports() {
      var n = ['setBadge', 'setExperimentalBadge', 'setClientBadge'];

      for (var _i = 0, _n = n; _i < _n.length; _i++) {
        var key = _n[_i];
        if (this.__navigator.hasOwnProperty(key)) return true;
      }

      return this.__window.hasOwnProperty('ExperimentalBadge');
    }
    /**
     * Wrapper to support first and second origin trial to compatible with the Browsers
     *
     * @private
     * @memberof  PWABadge
     * @see       https://web.dev/badging-api/
     * @see       https://github.com/w3c/badging/blob/master/docs/implementation.md
     * @returns   {Promise<void>} returns empty promise you can use for error handling
     */

  }, {
    key: "__innerSet",
    value: function __innerSet(unreadCount) {
      if (this.__navigator.setBadge) {
        return this.__navigator.setBadge(unreadCount);
      } else if (this.__navigator.setExperimentalBadge) {
        return this.__navigator.setExperimentalBadge(unreadCount);
      } else if (this.__navigator.setClientBadge) {
        return this.__navigator.setClientBadge(unreadCount);
      } else if (this.__window.ExperimentalBadge) {
        return this.__window.ExperimentalBadge.set(unreadCount);
      }

      return Promise.reject();
    }
    /**
     * Sets the PWA App's badge.
     *
     * If a value is provided, set the badge to the provided value otherwise, display a plain white dot (or other flag as reprobate to the platform)
     * Don't assume anything about how the user agent displays the badge.
     * Some user agents may take a number like "4000" and rewrite it as "99+".
     * If you saturate the badge yourself (for example by setting it to "99") then the "+" won't appear.
     * No matter the actual number, just call setAppBadge(unreadCount) and let the user agent deal with displaying it accordingly.
     *
     * Setting number to `0` is the same as calling {@link syncClearBadge|this.syncClearBadge()}.
     *
     * @memberof    PWABadge
     * @param       {number} unreadCount - Unread Badge count
     * @returns     {void}   returns empty promise you can use for error handling
     */

  }, {
    key: "syncSetBadge",
    value: function syncSetBadge(unreadCount) {
      try {
        this.__innerSet(unreadCount).catch(function (error) {
          throw error;
        });
      } catch (e) {
        return e;
      }
    }
    /**
     * Sets the PWA App's badge.
     *
     * If a value is provided, set the badge to the provided value otherwise, display a plain white dot (or other flag as reprobate to the platform)
     * Don't assume anything about how the user agent displays the badge.
     * Some user agents may take a number like "4000" and rewrite it as "99+".
     * If you saturate the badge yourself (for example by setting it to "99") then the "+" won't appear.
     * No matter the actual number, just call setAppBadge(unreadCount) and let the user agent deal with displaying it accordingly.
     *
     * Setting number to `0` is the same as calling {@link syncClearBadge|this.syncClearBadge()}.
     *
     * @async
     * @memberof    PWABadge
     * @param       {number} unreadCount - Unread Badge count
     * @returns     {Promise<void>} returns empty promise you can use for error handling
     */

  }, {
    key: "asyncSetBadge",
    value: function () {
      var _asyncSetBadge = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(count) {
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                return _context.abrupt("return", this.__innerSet(count));

              case 1:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function asyncSetBadge(_x) {
        return _asyncSetBadge.apply(this, arguments);
      }

      return asyncSetBadge;
    }()
    /**
     * Wrapper to support first and second origin trial to compatible with the Browsers
     *
     * @private
     * @memberof PWABadge
     * @see      https://web.dev/badging-api/
     * @see      https://github.com/w3c/badging/blob/master/docs/implementation.md
     * @returns  {Promise<void>} returns empty promise you can use for error handling
     */

  }, {
    key: "__innerClear",
    value: function __innerClear() {
      if (this.__navigator.clearBadge) {
        return this.__navigator.clearBadge();
      } else if (this.__navigator.clearExperimentalBadge) {
        return this.__navigator.clearExperimentalBadge();
      } else if (this.__window.ExperimentalBadge) {
        return this.__window.ExperimentalBadge.clear();
      } else if (this.__navigator.clearClientBadge) {
        return this.__navigator.clearClientBadge();
      }

      return Promise.reject();
    }
    /**
     * Removes app's badge.
     *
     * @memberof PWABadge
     * @returns  {void} returns empty promise you can use for error handling
     */

  }, {
    key: "syncClearBadge",
    value: function syncClearBadge() {
      try {
        this.__innerClear().catch(function (error) {
          throw error;
        });
      } catch (e) {
        return e;
      }
    }
    /**
     * Removes app's badge.
     *
     * @async
     * @memberof PWABadge
     * @returns  {Promise<void>} returns empty promise you can use for error handling
     */

  }, {
    key: "asyncClearBadge",
    value: function () {
      var _asyncClearBadge = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2() {
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                return _context2.abrupt("return", this.__innerClear());

              case 1:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function asyncClearBadge() {
        return _asyncClearBadge.apply(this, arguments);
      }

      return asyncClearBadge;
    }()
  }]);

  return PWABadge;
}();

var _default = PWABadge;
exports.default = _default;